structtags

package
v3.2.1+incompatible Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 2, 2019 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CheckJsonTags

func CheckJsonTags(o interface{}) (errs []error)

CheckJSONTags checks that the json tags on a struct are present and in lower camel case format and reports violations as errors. The function will only produce meaningful results when a struct is passed in. It returns a nil empty slice when passed other types of values.

Types

This section is empty.

Jump to